===========================================
COBalD - the Opportunistic Balancing Daemon
===========================================

.. image:: https://readthedocs.org/projects/cobald/badge/?version=latest
    :target: http://cobald.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/MaineKuehn/cobald.svg?branch=master
    :target: https://travis-ci.org/MaineKuehn/cobald
    :alt: Test Status

.. image:: https://codecov.io/gh/MaineKuehn/cobald/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/MaineKuehn/cobald
    :alt: Test Coverage

.. image:: https://img.shields.io/pypi/v/cobald.svg
    :alt: Available on PyPI
    :target: https://pypi.python.org/pypi/cobald/

.. image:: https://img.shields.io/github/license/MaineKuehn/cobald.svg
    :alt: License
    :target: https://github.com/MaineKuehn/cobald/blob/master/LICENSE.txt

The ``cobald`` library provides a framework and runtime for balancing opportunistic resources.
